@@ -7,6 +7,9 @@ except ImportError:
 from .datasets.service import DatasetService
 from .data.service import DataService
 from .slices.service import SliceService
+from .activities.service import ActivityService
+from .exports.service import ExportService
+from .contents.service import ContentService
 
 # Core Entities and Enums
 from .entities import (
@@ -19,12 +22,19 @@ from .entities import (
     DataMeta,
     Dataset,
     Slice,
-    
+    Activity,
+    ActivityHistory,
+    Export,
+    Content,
+
     # Enums
     DataType,
     SceneType,
     DataMetaTypes,
     DataMetaValue,
+    ActivityStatus,
+    ActivitySchema,
+    SchemaType,
 )
 
 # Filters
@@ -36,6 +46,10 @@ from .searches import (
     DatasetsFilterOptions,
     SlicesFilter,
     SlicesFilterOptions,
+    ActivitiesFilter,
+    ActivitiesFilterOptions,
+    ExportFilter,
+    ExportFilterOptions,
 )
 
 __all__ = (
@@ -43,7 +57,10 @@ __all__ = (
     "DatasetService",
     "DataService",
     "SliceService",
-    
+    "ActivityService",
+    "ExportService",
+    "ContentService",
+
     # Core Entities
     "Data",
     "Scene",
@@ -53,12 +70,19 @@ __all__ = (
     "DataMeta",
     "Dataset",
     "Slice",
+    "Activity",
+    "ActivityHistory",
+    "Export",
+    "Content",
     
     # Enums
     "DataType",
     "SceneType",
     "DataMetaTypes",
     "DataMetaValue",
+    "ActivityStatus",
+    "ActivitySchema",
+    "SchemaType",
     
     # Filters
     "AnnotationFilter",
@@ -68,4 +92,8 @@ __all__ = (
     "DatasetsFilterOptions",
     "SlicesFilter",
     "SlicesFilterOptions",
+    "ActivitiesFilter",
+    "ActivitiesFilterOptions",
+    "ExportFilter",
+    "ExportFilterOptions",
 )
