@@ -14,6 +14,15 @@ from .data.enums import (
     DataMetaTypes,
     DataMetaValue,
 )
+from .activities.entities import (
+    Activity,
+    ActivityHistory,
+    ActivityStatus,
+    ActivitySchema,
+    SchemaType,
+)
+from .exports.entities import Export
+from .contents.entities import Content
 
 __all__ = [
     # Core Entities
@@ -25,10 +34,17 @@ __all__ = [
     "DataMeta",
     "Dataset",
     "Slice",
-    
+    "Activity",
+    "ActivityHistory",
+    "Export",
+    "Content",
+
     # Enums
     "DataType",
     "SceneType",
     "DataMetaTypes",
     "DataMetaValue",
+    "ActivityStatus",
+    "ActivitySchema",
+    "SchemaType",
 ] 
\ No newline at end of file
