@@ -12,6 +12,14 @@ from .slices.params.slices import (
     SlicesFilterOptions,
     SlicesFilter,
 )
+from .activities.params.activities import (
+    ActivitiesFilter,
+    ActivitiesFilterOptions,
+)
+from .exports.params.exports import (
+    ExportFilter,
+    ExportFilterOptions,
+)
 
 __all__ = [
     "AnnotationFilter",
@@ -21,4 +29,8 @@ __all__ = [
     "DatasetsFilterOptions",
     "SlicesFilter",
     "SlicesFilterOptions",
+    "ActivitiesFilter",
+    "ActivitiesFilterOptions",
+    "ExportFilter",
+    "ExportFilterOptions",
 ]
